@@ -9,20 +9,21 @@ for path in glob.glob('../examples/*.py'):
 
 assert modules
 
-error = 0
+errors = []
 
 for path in modules:
-    if path.endswith('server.py'):
+    if path.endswith('server.py') or path.endswith('proxy.py'):
         print path, 'skipping'
     else:
         print path, 'running'
         sys.stdout.flush()
         res = os.system('%s %s' % (sys.executable, path))
         if res:
-            error = 1
             print path, 'failed'
+            errors.append(path)
     print '-----'
 
-if error:
+if errors:
+    print '\n\nFailures: %s' % ', '.join(errors)
     sys.exit(1)
 
