@@ -1,8 +1,5 @@
 """Supporting definitions for the Python regression tests."""
 
-if __name__ != 'greentest.test_support':
-    raise ImportError, 'test_support must be imported from the test package'
-
 import sys
 
 class Error(Exception):
